@@ -2,7 +2,7 @@
 
 from rmap.main import RMap
 from rmap.banner import banner
-from rmap.utils import check_ping
+from rmap.utils import check_ping, exec_cmd
 from configparser import ConfigParser
 import argparse
 import subprocess
